# Morrowind May Mod: Daedric Merchant

The player finds an item which, when used, summons a unique NPC merchant for
bartering with. As the player interacts more with this merchant, dialog and
quests become available. Completing these quests expands the merchant's
offering, provides dialog options, and more.

## Plan

### Part 1: Merchant

- The item
- The merchant
- The enchantment (i.e., the spell)

### Part 2: Dialog

- Include a different greeting based on geography?
- Could be fun to reference Creeper and Mudcrab Merchant

### Part 3: Evolving Inventory

- The merchant will make requests of specific items found throughout the
  game-world. Some for personal desire (who doesn't want a nice Colovian hat?),
  and some for trade to get the player more interesting items.
- Custom items?

### Part 4: Quests

- Some kind of quest involving the merchant, former clients, maybe a custom
  location or "hijacked" location to add in some mod lore?

### Part 5: Player House

- Always fun to have your own plane of Oblivion...

## Development

Working through the parts 1 and 2. Adding in items and NPCs is easy enough.
Creating a custom spell is more involved, and so I've opted against it. The
current implementation is a book which offers the options to summon a merchant
NPC, or pick up the book. Picking up the book activates it, resulting in the
player reading it and optionally taking it. Summoning the merchant spawns a
custom NPC in front of the player. An initial idea is to immediately start
dialog when the merchant is summoned (using the apt `ForceGreeting`). However,
given how the player summons the merchant (looking at a book in the worldspace),
it results in the player staring at the book, seeing the feet of the merchant.
Further, there is a script attached to the merchant that disables the merchant
when the dialog box is closed.

I'm very happy with this initial progress. I've more-or-less implemented my
original idea of a summonable merchant, in the style of Neverwinter Nights.
However, this implementation is not what I would like fully, and so the idea
evolves.

After playing around with the CS enough, I know that there are several things
which can expand my idea.

I'm going to add a faction, possibly hidden, which the player becomes a part of
when picking up the book. Initially, the player's reputation with this faction
only allows them to interact with an unfair and invisible representative through
the book. This is handled through dialog, likely from an invisible actor. The
inventory is limited, and prices are unfair. The player is told in the book how
to raise their reputation, and after doing so, will be rewarded with the
opportunity to summon a proper merchant. The reputation requirement will not be
too high, maybe 30, with rep increasing every time the player buys something in
addition to some kind of quest.

The merchant, once available, is then summoned and placed into the world at the
player as a full NPC. When spoken with, they warmly greet the player, and
possibly even comment on the current region. Unlike the default inventory, the
merchant will offer a smaller selection of better items, also improving and
expanding as player rep increases. The merchant also has quests.

At the higher rep levels, the player can visit a tradehouse of the faction. I'd
like for it to be a zone the player teleports to which exists outside the
Tamriel world space. I'd like for it to be like a small estate. There are
several gathering rooms, places for food a drink, and rooms the player can stay
in. Eventually, the player earns a permanent room at the tradehouse.

### Book - Inventory

As the book can be used anywhere, the inventory should be reasonable, and even
helpful, for an adventurer. I'll need to manipulate the mercantilism skills of
the book-merchant in order for prices to be unfair. The convenience of having an
anywhere merchant is not one to be taken lightly, or provided without some
costs. Perhaps there should be a cost for even accessing the inventory.

Should the inventory restock? If so, perhaps I can restock it at intervals?
Maybe the player can pay to restock it sooner?

What items should be sold? Adventurer items make the most sense. Things like
potions for health, fatigue, and mana; lockpicks and probes; sensible food and
drink options (whatever the equivalent of cheap wine, hard-tack, and water would
be); repair hammers; and scrolls for water walking, water breathing, and
levitate. The scrolls and potions can maybe be split better. The quality of
these items can be improved by paying for them to improve, and possibly also
requiring completing quests for the higher/highest levels.

As for improving over time, I think it may be easier to just have multiple NPCs
which can be enabled/disabled as the player's rank increases. The amount of
money the NPC has can also increase as the player's rank increases. At every
rank increase, the NPC gold increases (it's like a credit limit!), and at every
"title change" (Customer -> Partner -> Member) the quality of gear improves.

---

The implementation is to increase the player's "credit limit" (ie., the NPC gold
available to buy things) increases Ranks 1-6, maxing out at 700gp. Upon the
"title" changes (Customer -> Partner -> Member), the Clerk's inventory improves
in quality. Initially, the Clerk's inventory is extremely limited, and is
expanded through Trade Contracts, one of the quest types offered. The other
quest types offered are delivery quests and fetch quests.

1. **Trade Contracts:** Contracts expand the Clerk's inventory.

2. **Package Delivery:** Bring a package to a merchant, get paid, earn rep.

3. **Fetch Package:** Receive a package from a merchant for the Clerk, earn rep.

### Book - Quests

### Merchant - Inventory

### Merchant - Location Dialog

Based on where the player summons the merchant, their greeting will be
different. I'm thinking the merchant is knowledgable of, but not experienced
with, the locations they speak about. They can share information and rumors,
perhaps even indications of some in-game relevant hints or such, but they've
also never actually explored Morrowind.

Locations:

- Balmora
    "The few times I've seen Balmora it has always felt like home. Comfortable,
    somewhat familiar, despite this unfamiliar realm. Nice little river. Hard to
    complain about living in such a place."
- Vivec
    "So this is a city of a god? I suppose it's impressive. Does this god
    enforce trade as they do worship? Would they threaten annihilation by large
    rocks from the sky if deals went ary?"
- Dwemer Ruins
    "Our organization has records of trading with those you call the Dwemer. Big
    into technology. Very innovative. If you find any, pass along our interest
    in speaking with them about some debts."
- Ghostgate
- Tel Mora
- Tel Vos
- Ald'Ruhn
- Saeda Neen
- Ebonhawk

It would make sense to expand options to include locations from the Tameriel
Rebuilt, Skyrim, and Cyrodiil landspaces as well. This can come later.

### Merchant - Quests

- One requiring trading in a full set of Daedric armor, and in exchange being
  given a powerful artifact. Are there Daedric artifacts from lore or other
  games that aren't in Morrowind, and are they significant enough?
    - Certain thresholds of pieces, or specific pieces turned in could give some
    more mundane rewards, as a sort of progression. 
    - Obviously, if pieces are sold to the merchant, they are removed from it's
      inventory, but should still count towards this quest.

### Trade House - General

The trade house is a hub and home area. Initially, the player gains access and
can make use of the amenities listed below. After continuing to raise their
faction reputation, the trade house expands their inventory, and offers the
player a permanent room.

**Amenities:**

- The "book inventory" NPC is actually located at this trade house, and offers
  the same inventory, though in person, that they offered through the book.
- A bar area offers food and drink, as well as rooms to rent for the evening.
  Could be really cool to integrate some of the various game mods (Nine Holes,
  Thirteen Telvani) into this space as well.
- A small interior courtyard, with some nice artificial lighting, and a few
  plants which can be harvested. Should be of medium rarity.
- It could be neat to have a rotating collection of NPCs that each offer
  different services or unique inventories. For example, could be an alchemist
  that offers potions and ingredients some days, an enchanter with scrolls and
  souls on another, and a small mercenary company offering a wide array of
  trainers.

### Trade House - Quests

### Trade House - Player's Room

Roughly the size of a small apartment, the player's permanent room at the Trade
House offers several convenience factors. Obviously, the room comes with a bed
and bedroom furniture. A small entertaining area offers some respawning food and
drinks. A small garden offers a collection of rarer alchemical ingredients.

---

Some further considerations on names. The original place-holder name is
"Otherworldly Trade Caravan." The general idea/theme of a river seemed
appropriate. Currents and currency are an obvious similarity. The tides being a
good analogy for the movement of wealth. Checking into the lore and languages of
the Elder Scrolls games, I've discovered some translations that could work:

- In "Ayleidoon", the language of the Ayleids, `Relleis` is river, and
  `Aran`/`Ran` mean king, so `Rellerane` can translate literally to "River of
  Kings", which is a rather fancy way to describe trade.
- That word would work for the Falmer dialect as well.
- In the language of the Dunmer, it could be `Ouada Tong`, or "River Guild",
  adopting the water metaphor from the Ayleids, with what seems to be the
  traditional grouping word.
- No clear good options for Dwemer, though one would be nice.

Taking this then to something in common, I've considered the following:

- Caravan of Tides
- Brokerage of Tides
- Consortium of Tides
- Court of Tides

None _quite_ fit right. However, "Broker of Tides" sounds like an honorific, and
so the personalized merchant may use that -- `Vaunted El'Ladim, Broker of
Tides`, or `Vaunted Intercessor, El'Ladim, Broker of Tides` as suggested by
Minos, so as to include some religious phrasing.

Organization again - a cool bit of interaction could be modifying the name of
the organization based on race. The Altmer would use the Ayleidoon name; the
Dunmer would use `Ouada Tong`; the Bosmer uncertain; the Imperials and Nords
would both use the Cyrodiilic name; the khajit would have a name closer to the
original, maybe something like "Star-Wandering Caravan"; and the argonians may
just use the Dunmer, or Cyrodiilic too. Could be a nice little touch, maybe
specifically used when interacting with NPCs for the trade contracts. Also, a
bit more lore to build for the organization.
